# mpservice

Model serving with asyncio, multiprocessing, and batching.

Although the code uses some machine-learning terminology to name things, the use case is generic.

Reference: [Service Batching from Scratch, Again](https://zpz.github.io/blog/batched-service-redesign/).

To install, do `pip install mpservice`.